#!/bin/sh
#
# Guillaume LUCAS et Hamza HMAMA
# Licence : CC-BY-SA
#
# Ce script permet de signer toutes les zones pour une durée de 3 mois avant que le labo
# soit directement utilisable. Attention : il appartient à l'utilisateur de renouveler
# les clés (KSK et ZSK) manuellement.
#
# On aurait pu réaliser la signature dans chaque fichier startup correspondant
# à un serveur hébergeant une ou plusieurs zone(s) mais, étant donné que les clés
# ont été généré sur l'hôte pour des question d'entropie et que le signeur est
# une vieille version, la signature échoue (le format des fichiers stockant
# les parties privées des clés a changé, de v1.2 à v1.3).

DNSSEC_SIGNZONE=/usr/sbin/dnssec-signzone

# Sous Debian Wheezy, il faut être root pour avoir dnssec-signzone dans son PATH
if [ $USER != "root" ]
then
	echo "Vous devez executer ce script en étant root."
	exit 1
fi


if [ ! -x $DNSSEC_SIGNZONE ]
then
	echo "Vous devez installer le paquet bind9util sur l'hôte."
	exit 1
fi


$DNSSEC_SIGNZONE -o mycorporation.jide -e now+7776000 -3 `< /dev/random tr -dc A-F0-9 | head -c8` -K primaire/root -N "increment" primaire/etc/bind/master/master.mycorporation.jide
if [ $? -ne 0 ]
then
	echo "Erreur lors de la signature de mycorporation.jide."
	exit 1
fi

$DNSSEC_SIGNZONE -o 16.172.in-addr.arpa -e now+7776000 -3 `< /dev/random tr -dc A-F0-9 | head -c8` -K primaire/root -N "increment" primaire/etc/bind/master/master.172.16.rev
if [ $? -ne 0 ]
then
	echo "Erreur lors de la signature de 16.172.in-addr.arpa."
	exit 1
fi

$DNSSEC_SIGNZONE -o jide -e now+7776000 -3 `< /dev/random tr -dc A-F0-9 | head -c8` -K TLD/root -N "increment" TLD/etc/bind/master/master.jide
if [ $? -ne 0 ]
then
	echo "Erreur lors de la signature de jide."
	exit 1
fi

$DNSSEC_SIGNZONE -o in-addr.arpa -e now+7776000 -3 `< /dev/random tr -dc A-F0-9 | head -c8` -K TLD/root -N "increment" TLD/etc/bind/master/master.in-addr.arpa
if [ $? -ne 0 ]
then
	echo "Erreur lors de la signature de in-addr.arpa."
	exit 1
fi

$DNSSEC_SIGNZONE -o . -e now+7776000 -K racine/root -N "increment" racine/etc/bind/master/master.racine
if [ $? -ne 0 ]
then
	echo "Erreur lors de la signature de . ."
	exit 1
fi

$DNSSEC_SIGNZONE -o arpa -e now+7776000 -K racine/root -N "increment" racine/etc/bind/master/master.arpa
if [ $? -ne 0 ]
then
	echo "Erreur lors de la signature de arpa."
	exit 1
fi

rm dsset*

exit 0
